@@ -4,12 +4,20 @@
 # LICENSE file in the root directory of this source tree. An additional grant
 # of patent rights can be found in the PATENTS file in the same directory.
 #
-try:
-    import unittest2 as unittest
-except ImportError:
+import sys
+
+if sys.version < '2.7':
+    try:
+        import unittest2 as unittest
+    except ImportError:
+        raise Exception("unittest2 required for unit testing on versions "
+                        "prior to Python 2.7")
+else:
     import unittest
+
 import logging
 import os.path
+import warnings
 
 from sparts.vservice import VService
 
@@ -27,11 +35,16 @@ except ImportError:
 
 # Base test case for all sparts jonx
 class BaseSpartsTestCase(unittest.TestCase):
+    def assertEquals(self, a, b, msg=''):
+        super(BaseSpartsTestCase, self).assertEquals(a, b, msg)
+        warnings.warn("Deprecated in Python-3.x.  Use assertEqual instead.",
+                      DeprecationWarning)
+
     def assertNotNone(self, o, msg=''):
         self.assertTrue(o is not None, msg)
 
     def assertEmpty(self, arr, msg=''):
-        return self.assertEquals(len(arr), 0, msg)
+        return self.assertEqual(len(arr), 0, msg)
 
     def assertNotEmpty(self, o, msg=''):
         self.assertTrue(len(o) > 0, msg)
@@ -45,6 +58,9 @@ class BaseSpartsTestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls.logger = logging.getLogger('sparts.%s' % cls.__name__)
+
+        # Treat all warnings as errors when running unittests
+        warnings.simplefilter('error')
         super(BaseSpartsTestCase, cls).setUpClass()
 
     def setUp(self):
@@ -73,11 +89,15 @@ class BaseSpartsTestCase(unittest.TestCase):
 
     @property
     def mock(self, *args, **kwargs):
-        try:
-            import mock
-            return mock
-        except ImportError:
-            raise Skip("the mock module is required to run this test")
+        if sys.version < '3.3':
+            try:
+                import mock
+                return mock
+            except ImportError:
+                raise Skip("the mock module is required to run this test")
+        else:
+            import unittest.mock
+            return unittest.mock
 
 
 class ServiceTestCase(BaseSpartsTestCase):
