@@ -14,6 +14,8 @@ from thrift.protocol.TBinaryProtocol import TBinaryProtocol
 
 from functools import partial
 
+import sys
+
 
 class ThriftClient(object):
     """Base Class for easy interfacing with thrift services.
@@ -112,13 +114,28 @@ class ThriftClient(object):
         if self.path is None:
             self._socket = TSocket(self.host, self.port)
         else:
-            self._socket = THttpClient(self.host, self.port, self.path)
+            self._socket = THttpClient(self._makeConnectURI())
         self._socket.setTimeout(int(self.connect_timeout * 1000))
         self._transport = self.transport_class(self._socket)
         self._protocol = self.protocol_class(self._transport)
         self._client = self.module.Client(self._protocol)
         self._transport.open()
 
+    def _makeConnectURI(self):
+        assert self.path.startswith('/')
+        host = self.host
+        # If host is a v6 addr, we need to format the URI a little bit
+        # differently in order to parse its port out according to spec
+        if ':' in host:
+            assert sys.version >= '2.7', \
+                "Native v6 IP URLs not parseable on Python < 2.7"
+            host = '[{host}]'.format(host=host)
+        return 'http://{host}:{port}{path}'.format(
+            host=host,
+            port=self.port,
+            path=self.path,
+        )
+
     def _lazyCall(self, name, *args, **kwargs):
         if self._client is None:
             self._connect()
